=================
Functions
=================
.. currentmodule:: polars

Conversion
~~~~~~~~~~
.. autosummary::
   :toctree: api/

    from_arrow
    from_dataframe
    from_dict
    from_dicts
    from_numpy
    from_pandas
    from_records
    from_repr

Eager/Lazy functions
~~~~~~~~~~~~~~~~~~~~
.. autosummary::
   :toctree: api/

    arg_where
    concat
    cut
    date_range
    get_dummies
    ones
    zeros

Miscellaneous
~~~~~~~~~~~~~~~~~~~~
.. autosummary::
   :toctree: api/

    align_frames

Parallelization
~~~~~~~~~~~~~~~
.. autosummary::
   :toctree: api/

   collect_all

StringCache
~~~~~~~~~~~
.. autosummary::
   :toctree: api/

    enable_string_cache
    StringCache
